%define anolis_release 5

Name:           augeas
Version:        1.13.0
Release:        %{anolis_release}%{?dist}
Summary:        A library for changing configuration files
License:        LGPLv2+
URL:            https://github.com/hercules-team/augeas
Source0:        https://github.com/hercules-team/augeas/releases/download/release/%{name}-%{version}.tar.gz

Provides:       bundled(gnulib)

BuildRequires:  autoconf automake make
BuildRequires:  gcc libtool git flex
BuildRequires:  libxml2-devel readline-devel libselinux-devel

Requires:       %{name}-libs = %{version}-%{release}

%description
Augeas is a library and command line tool that focuses on the most basic problem in 
handling Linux configurations programmatically: editing actual configuration files 
in a controlled manner.

To that end, Augeas exposes a tree of all configuration settings (well, all the ones it knows about) 
and a simple local API for manipulating the tree. Augeas then modifies underlying configuration 
files according to the changes that have been made to the tree; it does as little modeling of 
configurations as possible, and focuses exclusively on transforming the tree-oriented syntax of 
its public API to the myriad syntaxes of individual configuration files.

%package        libs
Summary:        Libraries for %{name}

%description    libs
This package is a librarie for Augeas which is a library for programmatically editing configuration files. 
It parses configuration files into a tree structure, which it exposes through its public API. Changes 
made through the API are written back to the initially read files

%package        devel
Summary:        Development files for %{name}
Requires:       %{name}-libs = %{version}-%{release}
Requires:       pkgconfig

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%package        static
Summary:        Static libraries for %{name}
Requires:       %{name}-devel = %{version}-%{release}

%description    static
The %{name}-static package contains static libraries needed to produce
static builds using %{name}.

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name}-libs = %{version}-%{release}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%prep
%autosetup -p1

%build
%configure
%make_build

%check
export SKIP_TEST_PRESERVE_SELINUX=1
make check

%install
rm -rf %{buildroot}
make install DESTDIR=%{buildroot} INSTALL="%{__install} -p"

rm -r %{buildroot}%{_datadir}/augeas/lenses/dist/tests
rm -f %{buildroot}/usr/bin/dump

%generate_compatibility_deps

%files
%{_bindir}/augmatch
%{_bindir}/augparse
%{_bindir}/augtool
%{_bindir}/fadot
%{abidir}/augmatch-option.list
%{abidir}/fadot-option.list
%{abidir}/augtool-option.list
%doc %{_mandir}/man1/*
%{_datadir}/vim/vimfiles/syntax/augeas.vim
%{_datadir}/vim/vimfiles/ftdetect/augeas.vim

%files libs
%license COPYING
%{_datadir}/augeas/lenses/dist
%dir %{abidir}
%{_libdir}/*.so.*
%{abidir}/libaugeas.dump
%{abidir}/libfa.dump

%files devel
%{_includedir}/*
%{_libdir}/*.so
%{_libdir}/pkgconfig/augeas.pc

%files static
%{_libdir}/libaugeas.a
%{_libdir}/libfa.a

%files doc
%doc README AUTHORS NEWS INSTALL

%changelog
* Fri Apr 14 2023 yuanhui <yuanhui@linux.alibaba.com> - 1.13.0-5
- Optimize the spec file

* Mon Apr 03 2023 Chunmei Xu <xuchunmei@linux.alibaba.com> - 1.13.0-4
- remove unnecessary BuildRequires

* Fri Feb 10 2023 happy_orange <songnannan@linux.alibaba.com> - 1.13.0-3
- add generate compatibility scripts

* Thu Sep 29 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 1.13.0-2
- add doc package

* Thu Apr 14 2022 yuanhui <yuanhui@linux.alibaba.com> - 1.13.0-1
- Init augeas for anolis os 23
